.. bruker2nifti documentation master file, created by
   sphinx-quickstart on Fri Jul 28 10:16:25 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to bruker2nifti's documentation!
========================================

Medical image format converter: from raw `Bruker <http://imaging.mrc-cbu.cam.ac.uk/imaging/FormatBruker>`_
ParaVision to `NifTi <https://nifti.nimh.nih.gov/nifti-1>`_, written in Python.

+ Code repository `link <https://github.com/SebastianoF/bruker2nifti>`_
+ Wiki page and examples `link <https://github.com/SebastianoF/bruker2nifti/wiki>`_
+ Open issues `link <https://github.com/SebastianoF/bruker2nifti/issues>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
